You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@commons.apache.org by gg...@apache.org on 2018/05/30 17:17:19 UTC

commons-release-plugin git commit: Better ivar and method name.

Repository: commons-release-plugin
Updated Branches:
  refs/heads/master 90959a095 -> 8a4c5a37d


Better ivar and method name.

Project: http://git-wip-us.apache.org/repos/asf/commons-release-plugin/repo
Commit: http://git-wip-us.apache.org/repos/asf/commons-release-plugin/commit/8a4c5a37
Tree: http://git-wip-us.apache.org/repos/asf/commons-release-plugin/tree/8a4c5a37
Diff: http://git-wip-us.apache.org/repos/asf/commons-release-plugin/diff/8a4c5a37

Branch: refs/heads/master
Commit: 8a4c5a37df3bdd3a489c04a536f1b695831fab7f
Parents: 90959a0
Author: Gary Gregory <ga...@gmail.com>
Authored: Wed May 30 11:17:13 2018 -0600
Committer: Gary Gregory <ga...@gmail.com>
Committed: Wed May 30 11:17:13 2018 -0600

----------------------------------------------------------------------
 .../plugin/mojos/CommonsDistributionStagingMojo.java      | 10 +++++-----
 .../plugin/mojos/CommonsDistributionStagingMojoTest.java  |  2 +-
 2 files changed, 6 insertions(+), 6 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/commons-release-plugin/blob/8a4c5a37/src/main/java/org/apache/commons/release/plugin/mojos/CommonsDistributionStagingMojo.java
----------------------------------------------------------------------
diff --git a/src/test/java/org/apache/commons/release/plugin/mojos/CommonsDistributionStagingMojoTest.java b/src/test/java/org/apache/commons/release/plugin/mojos/CommonsDistributionStagingMojoTest.java
index 885ac3e..052ce60 100755
--- a/src/test/java/org/apache/commons/release/plugin/mojos/CommonsDistributionStagingMojoTest.java
+++ b/src/test/java/org/apache/commons/release/plugin/mojos/CommonsDistributionStagingMojoTest.java
@@ -73,7 +73,7 @@ public class CommonsDistributionStagingMojoTest {
         detachmentMojo = (CommonsDistributionDetachmentMojo) rule.lookupMojo("detach-distributions", detachmentPom);
         detachmentMojo.execute();
         File releaseNotesBasedir = new File("src/test/resources/mojos/stage-distributions/");
-        mojoForTest.setBasedir(releaseNotesBasedir);
+        mojoForTest.setBaseDir(releaseNotesBasedir);
         mojoForTest.execute();
         File targetScmDirectory = new File(COMMONS_RELEASE_PLUGIN_TEST_DIR_PATH + "/scm");
         File releaseNotes = new File(COMMONS_RELEASE_PLUGIN_TEST_DIR_PATH + "/scm/RELEASE-NOTES.txt");
diff --git a/src/main/java/org/apache/commons/release/plugin/mojos/CommonsDistributionStagingMojo.java b/src/main/java/org/apache/commons/release/plugin/mojos/CommonsDistributionStagingMojo.java
index 6bbd980..150781b 100755
--- a/src/main/java/org/apache/commons/release/plugin/mojos/CommonsDistributionStagingMojo.java
+++ b/src/main/java/org/apache/commons/release/plugin/mojos/CommonsDistributionStagingMojo.java
@@ -73,7 +73,7 @@ public class CommonsDistributionStagingMojo extends AbstractMojo {
      * this directory is where the <code>pom.xml</code> resides.
      */
     @Parameter(defaultValue = "${basedir}")
-    private File basedir;
+    private File baseDir;
 
     /**
      * The main working directory for the plugin, namely <code>target/commons-release-plugin</code>, but
@@ -388,13 +388,13 @@ public class CommonsDistributionStagingMojo extends AbstractMojo {
     }
 
     /**
      * This method is the setter for the {@link CommonsDistributionStagingMojo#basedir} field, specifically
      * for the usage in the unit tests.
      *
      * @param basedir is the {@link File} to be used as the project's root directory when this mojo
      *                is invoked.
      */
-    protected void setBasedir(File basedir) {
-        this.basedir = basedir;
+    protected void setBaseDir(File baseDir) {
+        this.baseDir = baseDir;
     }
 }

http://git-wip-us.apache.org/repos/asf/commons-release-plugin/blob/8a4c5a37/src/test/java/org/apache/commons/release/plugin/mojos/CommonsDistributionStagingMojoTest.java
----------------------------------------------------------------------
@@ -388,13 +388,13 @@ public class CommonsDistributionStagingMojo extends AbstractMojo {
 
     /**
-     * This method is the setter for the {@link CommonsDistributionStagingMojo#basedir} field, specifically
+     * This method is the setter for the {@link CommonsDistributionStagingMojo#baseDir} field, specifically
      * for the usage in the unit tests.
      *
@@ -388,13 +388,13 @@ public class CommonsDistributionStagingMojo extends AbstractMojo {
      * for the usage in the unit tests.
      *
-     * @param basedir is the {@link File} to be used as the project's root directory when this mojo
+     * @param baseDir is the {@link File} to be used as the project's root directory when this mojo
      *                is invoked.
      */